'use strict';

var MicroEvent = require('microevent');

var gapi_loaded = false;
var gapi_loaded_cb = null

window.onApiLoad = function() {
	gapi_loaded = true;
	if(gapi_loaded_cb) {
		gapi_loaded_cb();
	}
}

function GooglePicker(button, sio, options) {
	var that = this;

	var token = null;
	var picker = null;

	function pickerCallback(data) {
		if (data[google.picker.Response.ACTION] == google.picker.Action.PICKED) {
	    var file = data[google.picker.Response.DOCUMENTS][0];
	    var uri = 'https://www.googleapis.com/drive/v2/files/' + file.id + '?alt=media';
	    $.post(options.route, {
	    	uri: uri,
	    	token: token,
	    	name: file.name,
				sid: sio.id
	    });
	    that.trigger('start');
	  }
	}

	function getView() {
		if(options.view ===  'video') {
			return google.picker.ViewId.DOCS_VIDEOS;
		}
		// FIXME: Add more vie types
	}

	function createPicker() {
		var picker = new google.picker.PickerBuilder().
			addView(getView()).
			setOAuthToken(token).
			setDeveloperKey(options.apiKey).
			setCallback(pickerCallback).
			build();
	  picker.setVisible(true);
  }

	function loadGapi(done) {
		gapi.auth.init(function(){
			var opts = {
				'client_id': options.clientId,
				'scope': options.scope,
				'immediate': false
			};
			gapi.auth.authorize(opts, function(result) {
				if(result && !result.error) {
					token = result.access_token;
					gapi.load('picker', done);
				}
			});
		});
	}

	if(!gapi_loaded) {
		button.attr('disabled', true);
		gapi_loaded_cb = function() {
			button.attr('disabled', false);
		};
	}

	button.on('click', function() {
		button.blur();
		if(token) {
			createPicker();
		} else {
			loadGapi(createPicker);
		}
	});

	this.cancel = function() {
		sio.emit('cancel-google');
	}

  sio.on('update-google', function(status) {
  	that.trigger('update', status);
  });

  sio.on('ready-google', function(code, info) {
  	that.trigger('done', code, info);
  });
}

MicroEvent.mixin(GooglePicker);

module.exports = GooglePicker;
